@@ -17,19 +17,6 @@ import urllib.error
 from urllib import parse
 from urllib import request
 
-try:
-    # Debian: http://code.google.com/p/py-leveldb/
-    from leveldb import LevelDB
-    leveldb_imported = True
-except ImportError as e:
-    try:
-        # Fedora: https://github.com/wbolster/plyvel
-        from plyvel import DB as LevelDB
-        leveldb_imported = True
-    except ImportError as e:
-        leveldb_imported = False
-        print('Warning: No leveldb/plyvel module was found, http requests will not be cached!')
-
 from kuwo import Config
 from kuwo import Utils
 
@@ -54,16 +41,33 @@ class Dict(dict):
     pass
 req_cache = Dict()
 
-# Using leveldb to cache urlrequest
+try:
+    # Debian: http://code.google.com/p/py-leveldb/
+    from leveldb import LevelDB
+    ldb_imported = True
+except ImportError as e:
+    try:
+        # Fedora: https://github.com/wbolster/plyvel
+        from plyvel import DB as LevelDB
+        ldb_imported = True
+    except ImportError as e:
+        print('Warning: No leveldb/plyvel module was found')
+        ldb_imported = False
+
 ldb = None
-if leveldb_imported:
-    #ldb = LevelDB(Config.CACHE_DB, create_if_missing=True)
+if ldb_imported:
     try:
         ldb = LevelDB(Config.CACHE_DB, create_if_missing=True)
     except Exception as e:
-        print(e, type(e))
         print('Warning: Only one process can run at a time, quit!')
         sys.exit(1)
+    # support plyvel 0.6
+    if hasattr(ldb, 'put'):
+        ldb_get = ldb.get
+        ldb_put = ldb.put
+    else:
+        ldb_get = ldb.Get
+        ldb_put = ldb.Put
 
 def empty_func(*args, **kwds):
     pass
@@ -95,9 +99,11 @@ def urlopen(_url, use_cache=True, retries=MAXTIMES):
     url = _url.replace(':81', '')
     # hash the url to accelerate string compare speed in db.
     key = hash_byte(url)
-    if use_cache and leveldb_imported:
+    if use_cache and ldb_imported:
         try:
-            return ldb.Get(key)
+            content = ldb_get(key)
+            if content is not None:
+                return content
         except KeyError:
             pass
     retried = 0
@@ -105,8 +111,8 @@ def urlopen(_url, use_cache=True, retries=MAXTIMES):
         try:
             req = request.urlopen(url, timeout=TIMEOUT)
             req_content = req.read()
-            if use_cache and leveldb_imported:
-                ldb.Put(key, req_content)
+            if use_cache and ldb_imported:
+                ldb_put(key, req_content)
             return req_content
         except Exception as e:
             print('Error: Net.urlopen', e, 'url:', url)
